==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/CalloutStyleUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutStyleUpdatingEventArgsDescription } from "./CalloutStyleUpdatingEventArgsDescription";
/**
 * @hidden
 */
var CalloutStyleUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CalloutStyleUpdatingEventArgsDescriptionMetadata, _super);
    function CalloutStyleUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutStyleUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutStyleUpdatingEventArgsDescriptionMetadata.a == null) {
            CalloutStyleUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutStyleUpdatingEventArgsDescriptionMetadata.c(CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.j(CalloutStyleUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutStyleUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("Series", "ExportedType:Series");
        a.item("Background", "Brush");
        a.item("TextColor", "Brush");
        a.item("Outline", "Brush");
        a.item("LeaderBrush", "Brush");
        a.item("StrokeThickness", "Number:double");
    };
    CalloutStyleUpdatingEventArgsDescriptionMetadata.d = function (a) {
        CalloutStyleUpdatingEventArgsDescriptionMetadata.b(a);
        a.aa("CalloutStyleUpdatingEventArgs", function () { return new CalloutStyleUpdatingEventArgsDescription(); });
        a.z("CalloutStyleUpdatingEventArgs", CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutStyleUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutStyleUpdatingEventArgsDescriptionMetadata, 'CalloutStyleUpdatingEventArgsDescriptionMetadata');
    CalloutStyleUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutStyleUpdatingEventArgsDescriptionMetadata;
}(Base));
export { CalloutStyleUpdatingEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/CalloutStyleUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutStyleUpdatingEventArgsDescription } from "./CalloutStyleUpdatingEventArgsDescription";
/**
 * @hidden
 */
var CalloutStyleUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CalloutStyleUpdatingEventArgsDescriptionMetadata, _super);
    function CalloutStyleUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutStyleUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutStyleUpdatingEventArgsDescriptionMetadata.a == null) {
            CalloutStyleUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutStyleUpdatingEventArgsDescriptionMetadata.c(CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(CalloutStyleUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutStyleUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("Series", "ExportedType:Series");
        a.item("Background", "Brush");
        a.item("TextColor", "Brush");
        a.item("Outline", "Brush");
        a.item("LeaderBrush", "Brush");
        a.item("StrokeThickness", "Number:double");
    };
    CalloutStyleUpdatingEventArgsDescriptionMetadata.d = function (a) {
        CalloutStyleUpdatingEventArgsDescriptionMetadata.b(a);
        a.ac("CalloutStyleUpdatingEventArgs", function () { return new CalloutStyleUpdatingEventArgsDescription(); });
        a.ab("CalloutStyleUpdatingEventArgs", CalloutStyleUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutStyleUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutStyleUpdatingEventArgsDescriptionMetadata, 'CalloutStyleUpdatingEventArgsDescriptionMetadata');
    CalloutStyleUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutStyleUpdatingEventArgsDescriptionMetadata;
}(Base));
export { CalloutStyleUpdatingEventArgsDescriptionMetadata };
